@@ -1,6 +1,6 @@
 // Kinetophone_build_manager.cpp
 //
-// Copyright 2011-2012 Roan Trail, Inc.
+// Copyright 2011-2013 Roan Trail, Inc.
 //
 // This file is part of Kinetophone.
 //
@@ -24,19 +24,21 @@
 #include "Kinetophone_builder_config.hpp"
 #include "Kinetophone_builder_model.hpp"
 #include "Kinetophone_movie_builder.hpp"
-#include "../base/File_manager.hpp"
-#include "../base/Logger.hpp"
-#include "../base/Movie.hpp"
-#include "../base/Movie_builder_config.hpp"
-#include "../base/Movie_config.hpp"
-#include "../base/Segment.hpp"
-#include "../base/Slide.hpp"
-#include "../base/Slide_collection.hpp"
-#include "../base/Sound_builder.hpp"
-#include "../base/Sound_file_config.hpp"
-#include "../base/Sound_track.hpp"
-#include "../base/error/Kinetophone_error.hpp"
-#include "../base/error/Build_error.hpp"
+#include <kinetophone/common.hpp>
+#include <kinetophone/File_manager.hpp>
+#include <kinetophone/Image_types.hpp>
+#include <kinetophone/Logger.hpp>
+#include <kinetophone/Movie.hpp>
+#include <kinetophone/Movie_builder_config.hpp>
+#include <kinetophone/Movie_config.hpp>
+#include <kinetophone/Segment.hpp>
+#include <kinetophone/Slide.hpp>
+#include <kinetophone/Slide_collection.hpp>
+#include <kinetophone/Sound_builder.hpp>
+#include <kinetophone/Sound_file_config.hpp>
+#include <kinetophone/Sound_track.hpp>
+#include <kinetophone/error/Kinetophone_error.hpp>
+#include <kinetophone/error/Build_error.hpp>
 #include <iomanip>
 #include <sstream>
 #include <string>
@@ -51,15 +53,23 @@ using std::setfill;
 using std::setw;
 using std::string;
 using std::vector;
-using Roan_trail::Logger;
-using Roan_trail::Recorder::Segment;
-using Roan_trail::Source::Slide;
-using Roan_trail::Recorder::Sound_file_config;
-using Roan_trail::Builder::Movie_builder_config;
-using Roan_trail::Builder::Movie_config;
-using Roan_trail::Builder::Sound_track;
-using Roan_trail::Builder::Build_error;
-using namespace Roan_trail::Kinetophone;
+using Roan_trail::Kinetophone::File_manager;
+using Roan_trail::Kinetophone::Long_int;
+using Roan_trail::Kinetophone::Logger;
+using Roan_trail::Kinetophone::min;
+using Roan_trail::Kinetophone::max;
+using Roan_trail::Kinetophone::Movie_builder_config;
+using Roan_trail::Kinetophone::Movie_config;
+using Roan_trail::Kinetophone::Rect_size;
+using Roan_trail::Kinetophone::Segment;
+using Roan_trail::Kinetophone::Slide;
+using Roan_trail::Kinetophone::Sound_file_config;
+using Roan_trail::Kinetophone::Sound_track;
+using Roan_trail::Kinetophone::Build_error;
+using Roan_trail::Kinetophone::Error;
+using Roan_trail::Kinetophone::Error_param;
+using Roan_trail::Kinetophone::Kinetophone_error;
+using namespace Roan_trail::Kinetophone_app;
 
 //
 // Internal helpers
