@@ -1,6 +1,6 @@
 // Kinetophone_build_manager.hpp
 //
-// Copyright 2012 Roan Trail, Inc.
+// Copyright 2012-2013 Roan Trail, Inc.
 //
 // This file is part of Kinetophone.
 //
@@ -16,19 +16,22 @@
 // a copy of the GNU General Public License along with Kinetophone. If
 // not, see <http://www.gnu.org/licenses/>.
 
-#ifndef KINETOPHONE_BUILD_MANAGER_HPP_
-#define KINETOPHONE_BUILD_MANAGER_HPP_
+#ifndef ROAN_TRAIL_KINETOPHONE_APP_KINETOPHONE_BUILD_MANAGER_HPP_
+#define ROAN_TRAIL_KINETOPHONE_APP_KINETOPHONE_BUILD_MANAGER_HPP_
 
-#include "../base/common.hpp"
+#include <kinetophone/common.hpp>
 #include <string>
 
 namespace Roan_trail
 {
-  class Error;
-  class Error_param;
-  class Logger;
-
   namespace Kinetophone
+  {
+    class Error;
+    class Error_param;
+    class Logger;
+  }
+
+  namespace Kinetophone_app
   {
     struct Kinetophone_builder_config;
     class Kinetophone_builder_model;
@@ -47,9 +50,9 @@ namespace Roan_trail
       // mutators
       void reset_cancel() {  __sync_and_and_fetch(&m_cancelled, 0x0); }
       // control
-      bool setup_for_build(Error_param& return_error);
-      bool prebuild_checks(Error_param& return_error);
-      bool build(Error_param& return_error);
+      bool setup_for_build(Roan_trail::Kinetophone::Error_param& return_error);
+      bool prebuild_checks(Roan_trail::Kinetophone::Error_param& return_error);
+      bool build(Roan_trail::Kinetophone::Error_param& return_error);
       void cancel() {  __sync_or_and_fetch(&m_cancelled, 0x1); }
     protected:
       // invariant check
@@ -57,7 +60,7 @@ namespace Roan_trail
     private:
       const Kinetophone_builder_config& m_config;
       const Kinetophone_builder_model& m_model;
-      Logger& m_logger;
+      Roan_trail::Kinetophone::Logger& m_logger;
       //
       std::string m_source_sound_file_path;
       //
@@ -74,7 +77,7 @@ namespace Roan_trail
       void mf_log_model(const Kinetophone_movie_builder& builder);
       void mf_log_temporary_movies(const Kinetophone_movie_builder& builder);
       // log warning
-      void mf_log_warning(const Error* warning, bool output_separator = true);
+      void mf_log_warning(const Roan_trail::Kinetophone::Error* warning, bool output_separator = true);
       // prevent compiler from generating
       Kinetophone_build_manager(const Kinetophone_build_manager& m);
       Kinetophone_build_manager& operator=(const Kinetophone_build_manager& m);
@@ -82,4 +85,4 @@ namespace Roan_trail
   }
 }
 
-#endif // KINETOPHONE_BUILD_MANAGER_HPP_
+#endif // ROAN_TRAIL_KINETOPHONE_APP_KINETOPHONE_BUILD_MANAGER_HPP__
