@@ -1,6 +1,6 @@
 // Kinetophone_builder_app.hpp
 //
-// Copyright 2011-2012 Roan Trail, Inc.
+// Copyright 2011-2013 Roan Trail, Inc.
 //
 // This file is part of Kinetophone.
 //
@@ -16,23 +16,26 @@
 // a copy of the GNU General Public License along with Kinetophone. If
 // not, see <http://www.gnu.org/licenses/>.
 
-#ifndef KINETOPHONE_BUILDER_APP_HPP_
-#define KINETOPHONE_BUILDER_APP_HPP_
+#ifndef ROAN_TRAIL_KINETOPHONE_APP_KINETOPHONE_BUILDER_APP_HPP_
+#define ROAN_TRAIL_KINETOPHONE_APP_KINETOPHONE_BUILDER_APP_HPP_
 
-#include "../base/Application.hpp"
+#include <kinetophone/Application.hpp>
 #include <string>
 
 namespace Roan_trail
 {
-  class Error_param;
-
   namespace Kinetophone
+  {
+    class Error_param;
+  }
+
+  namespace Kinetophone_app
   {
     class Kinetophone_builder_config;
     class Kinetophone_builder_model;
     class Kinetophone_build_manager;
 
-    class Kinetophone_builder_app : public Application
+    class Kinetophone_builder_app : public Roan_trail::Kinetophone::Application
     {
     public:
       // Constructor/destructor/copy
@@ -49,7 +52,7 @@ namespace Roan_trail
       Kinetophone_builder_model* m_model;
       Kinetophone_build_manager* m_build_manager;
       //
-      bool mf_build(Error_param& return_error);
+      bool mf_build(Roan_trail::Kinetophone::Error_param& return_error);
       // prevent compiler from generating
       Kinetophone_builder_app(const Kinetophone_builder_app& app);
       Kinetophone_builder_app& operator=(const Kinetophone_builder_app& app);
@@ -57,4 +60,4 @@ namespace Roan_trail
   }
 }
 
-#endif // KINETOPHONE_BUILDER_APP_HPP_
+#endif // ROAN_TRAIL_KINETOPHONE_APP_KINETOPHONE_BUILDER_APP_HPP_
