@@ -17,15 +17,15 @@
 // not, see <http://www.gnu.org/licenses/>.
 
 #include "Kinetophone_builder_config.hpp"
-#include "../base/File_manager.hpp"
-#include "../base/Image_types.hpp"
-#include "../base/Movie_builder_config.hpp"
-#include "../base/Movie_config.hpp"
-#include "../base/option_checks.hpp"
-#include "../base/Option_validators.hpp"
-#include "../base/Sound_file_config.hpp"
-#include "../base/error/Boost_error.hpp"
-#include "../base/error/Kinetophone_error.hpp"
+#include <kinetophone/File_manager.hpp>
+#include <kinetophone/Image_types.hpp>
+#include <kinetophone/Movie_builder_config.hpp>
+#include <kinetophone/Movie_config.hpp>
+#include <kinetophone/option_checks.hpp>
+#include <kinetophone/Option_validators.hpp>
+#include <kinetophone/Sound_file_config.hpp>
+#include <kinetophone/error/Boost_error.hpp>
+#include <kinetophone/error/Kinetophone_error.hpp>
 #include <boost/program_options.hpp>
 #include <boost/concept/assert.hpp>
 #include <boost/concept_check.hpp>
@@ -41,19 +41,22 @@ using std::ifstream;
 using std::logic_error;
 using std::string;
 using std::stringstream;
-using Roan_trail::Color;
-using Roan_trail::File_manager;
-using Roan_trail::Options::check_conflicting_options;
-using Roan_trail::Options::check_option_dependency;
-using Roan_trail::Options::Color_validator;
-using Roan_trail::Options::Directory_validator;
-using Roan_trail::Options::Fraction_validator;
-using Roan_trail::Options::Positive_double_validator;
-using Roan_trail::Options::Positive_int_validator;
-using Roan_trail::Options::Str_to_int_lookup_validator;
-using Roan_trail::Options::Validator;
-using Roan_trail::Builder::Movie_builder_config;
-using namespace Roan_trail::Kinetophone;
+using Roan_trail::Kinetophone::Color;
+using Roan_trail::Kinetophone::File_manager;
+using Roan_trail::Kinetophone::check_conflicting_options;
+using Roan_trail::Kinetophone::check_option_dependency;
+using Roan_trail::Kinetophone::Color_validator;
+using Roan_trail::Kinetophone::Directory_validator;
+using Roan_trail::Kinetophone::Fraction_validator;
+using Roan_trail::Kinetophone::Positive_double_validator;
+using Roan_trail::Kinetophone::Positive_int_validator;
+using Roan_trail::Kinetophone::Str_to_int_lookup_validator;
+using Roan_trail::Kinetophone::Validator;
+using Roan_trail::Kinetophone::Movie_builder_config;
+using Roan_trail::Kinetophone::Boost_error;
+using Roan_trail::Kinetophone::Error_param;
+using Roan_trail::Kinetophone::Kinetophone_error;
+using namespace Roan_trail::Kinetophone_app;
 
 namespace PO = boost::program_options;
 
@@ -63,9 +66,9 @@ namespace PO = boost::program_options;
 
 namespace
 {
-  using Roan_trail::Recorder::Sound_file_config;
-  using Roan_trail::Builder::Movie_config;
-  using Roan_trail::Builder::Movie_builder_config;
+  using Roan_trail::Kinetophone::Sound_file_config;
+  using Roan_trail::Kinetophone::Movie_config;
+  using Roan_trail::Kinetophone::Movie_builder_config;
 
   //
   // some custom validation code for this configuration
@@ -527,8 +530,8 @@ const int Kinetophone_builder_config::command_help;
 const int Kinetophone_builder_config::command_output_version;
 
 int Kinetophone_builder_config::parse_program_options(int argc,
-                                                       const char** argv,
-                                                       Error_param& return_error)
+                                                      const char** argv,
+                                                      Error_param& return_error)
 {
   precondition(!return_error());
 
