@@ -1,6 +1,6 @@
 // Kinetophone_builder_view.cpp
 //
-// Copyright 2012 Roan Trail, Inc.
+// Copyright 2012-2013 Roan Trail, Inc.
 //
 // This file is part of Kinetophone.
 //
@@ -17,8 +17,8 @@
 // not, see <http://www.gnu.org/licenses/>.
 
 #include "Kinetophone_builder_view.hpp"
-#include "../base/common.hpp"
-#include "../base/error/Error.hpp"
+#include <kinetophone/common.hpp>
+#include <kinetophone/error/Error.hpp>
 #include <iostream>
 #include <string>
 
@@ -26,8 +26,8 @@ using std::cout;
 using std::cerr;
 using std::endl;
 using std::string;
-
-using namespace Roan_trail::Kinetophone;
+using Roan_trail::Kinetophone::Error;
+using namespace Roan_trail::Kinetophone_app;
 
 //
 // Constructor/destructor
