@@ -1,6 +1,6 @@
 // Kinetophone_builder_view.hpp
 //
-// Copyright 2012 Roan Trail, Inc.
+// Copyright 2012-2013 Roan Trail, Inc.
 //
 // This file is part of Kinetophone.
 //
@@ -16,16 +16,19 @@
 // a copy of the GNU General Public License along with Kinetophone. If
 // not, see <http://www.gnu.org/licenses/>.
 
-#ifndef KINETOPHONE_BUILDER_VIEW_HPP_
-#define KINETOPHONE_BUILDER_VIEW_HPP_
+#ifndef ROAN_TRAIL_KINETOPHONE_APP_KINETOPHONE_BUILDER_VIEW_HPP_
+#define ROAN_TRAIL_KINETOPHONE_APP_KINETOPHONE_BUILDER_VIEW_HPP_
 
 #include <string>
 
 namespace Roan_trail
 {
-  class Error;
-
   namespace Kinetophone
+  {
+    class Error;
+  }
+
+  namespace Kinetophone_app
   {
     class Kinetophone_builder_view
     {
@@ -34,7 +37,7 @@ namespace Roan_trail
       Kinetophone_builder_view() {}
       // commands
       static void output_message(const std::string& message);
-      static void output_error(const Error* error);
+      static void output_error(const Roan_trail::Kinetophone::Error* error);
       static void output_error(const std::string& message);
     protected:
       // invariant check
@@ -47,4 +50,4 @@ namespace Roan_trail
   }
 }
 
-#endif // KINETOPHONE_BUILDER_VIEW_HPP_
+#endif // ROAN_TRAIL_KINETOPHONE_APP_KINETOPHONE_BUILDER_VIEW_HPP_
