@@ -1,6 +1,6 @@
 // Kinetophone_movie_builder.hpp
 //
-// Copyright 2012 Roan Trail, Inc.
+// Copyright 2012-2013 Roan Trail, Inc.
 //
 // This file is part of Kinetophone.
 //
@@ -16,28 +16,29 @@
 // a copy of the GNU General Public License along with Kinetophone. If
 // not, see <http://www.gnu.org/licenses/>.
 
-#ifndef KINETOPHONE_MOVIE_BUILDER_HPP_
-#define KINETOPHONE_MOVIE_BUILDER_HPP_
+#ifndef ROAN_TRAIL_KINETOPHONE_APP_KINETOPHONE_MOVIE_BUILDER_HPP_
+#define ROAN_TRAIL_KINETOPHONE_APP_KINETOPHONE_MOVIE_BUILDER_HPP_
 
-#include "../base/common.hpp"
-#include "../base/Movie_builder.hpp"
+#include <kinetophone/common.hpp>
+#include <kinetophone/Movie_builder.hpp>
 #include <gdkmm/pixbuf.h>
 
 namespace Roan_trail
 {
-  namespace Kinetophone
+  namespace Kinetophone_app
   {
     struct Kinetophone_builder_config;
     class Kinetophone_builder_model;
 
-    class Kinetophone_movie_builder : public Roan_trail::Builder::Movie_builder
+    class Kinetophone_movie_builder : public Roan_trail::Kinetophone::Movie_builder
     {
     public:
       Kinetophone_movie_builder(const Kinetophone_builder_config& config,
                                 const Kinetophone_builder_model& model);
       virtual ~Kinetophone_movie_builder();
     protected:
-      virtual const uint8_t* mf_generate_image(Long_int slide_index, bool& return_used_default);
+      virtual const uint8_t* mf_generate_image(Roan_trail::Kinetophone::Long_int slide_index,
+                                               bool& return_used_default);
       // invariant check
       bool mf_invariant(bool check_base_class = true) const;
     private:
@@ -52,4 +53,4 @@ namespace Roan_trail
   }
 }
 
-#endif // KINETOPHONE_MOVIE_BUILDER_HPP_
+#endif // ROAN_TRAIL_KINETOPHONE_APP_KINETOPHONE_MOVIE_BUILDER_HPP_
