@@ -1,6 +1,6 @@
 // Console_app.cpp
 //
-// Copyright 2011-2012 Roan Trail, Inc.
+// Copyright 2011-2013 Roan Trail, Inc.
 //
 // This file is part of Kinetophone.
 //
@@ -17,14 +17,16 @@
 // not, see <http://www.gnu.org/licenses/>.
 
 #include "Console_app.hpp"
-#include "../base/common.hpp"
-#include "../base/error/Curses_error.hpp"
+#include <kinetophone/common.hpp>
+#include <kinetophone/error/Curses_error.hpp>
 #include <string>
 #include <cstdlib>
 #include <ncurses.h>
 
 using std::string;
-using namespace Roan_trail;
+using Roan_trail::Kinetophone::Curses_error;
+using Roan_trail::Kinetophone::Error_param;
+using namespace Roan_trail::Kinetophone_app;
 
 //
 // Constructor/destructor
