@@ -1,6 +1,6 @@
 // Console_controller.cpp
 //
-// Copyright 2011-2012 Roan Trail, Inc.
+// Copyright 2011-2013 Roan Trail, Inc.
 //
 // This file is part of Kinetophone.
 //
@@ -18,7 +18,7 @@
 
 #include "Console_controller.hpp"
 
-using namespace Roan_trail;
+using namespace Roan_trail::Kinetophone_app;
 
 //
 // Protected member functions
