@@ -1,6 +1,6 @@
 // Kinetophone_console_app.cpp
 //
-// Copyright 2011-2012 Roan Trail, Inc.
+// Copyright 2011-2013 Roan Trail, Inc.
 //
 // This file is part of Kinetophone.
 //
@@ -17,15 +17,15 @@
 // not, see <http://www.gnu.org/licenses/>.
 
 #include "Kinetophone_console_app.hpp"
-#include "../base/Kinetophone_model.hpp"
-#include "../base/File_manager.hpp"
-#include "../base/Sound_recorder.hpp"
-#include "../base/Sound_recorder_config.hpp"
-#include "../base/Sound_file_config.hpp"
+#include <kinetophone/Kinetophone_model.hpp>
+#include <kinetophone/File_manager.hpp>
+#include <kinetophone/Sound_recorder.hpp>
+#include <kinetophone/Sound_recorder_config.hpp>
+#include <kinetophone/Sound_file_config.hpp>
 #include "Kinetophone_console_view.hpp"
 #include "Kinetophone_console_controller.hpp"
 #include "Kinetophone_console_config.hpp"
-#include "../base/error/Kinetophone_error.hpp"
+#include <kinetophone/error/Kinetophone_error.hpp>
 #include <portaudio.h>
 #include <sstream>
 #include <string>
@@ -42,9 +42,12 @@
 using std::endl;
 using std::string;
 using std::stringstream;
-using Roan_trail::Console_app;
-using Roan_trail::Recorder::Sound_recorder;
-using namespace Roan_trail::Kinetophone;
+using Roan_trail::Kinetophone::Kinetophone_model;
+using Roan_trail::Kinetophone::Sound_recorder;
+using Roan_trail::Kinetophone::Error;
+using Roan_trail::Kinetophone::Error_param;
+using Roan_trail::Kinetophone::Kinetophone_error;
+using namespace Roan_trail::Kinetophone_app;
 
 //
 // Constructor/destructor/copy
@@ -165,7 +168,7 @@ void Kinetophone_console_app::terminate(int code, const string& message)
   precondition(mf_invariant());
 
   Sound_recorder *recorder = m_model->sound_recorder();
-  if (Roan_trail::Recorder::Recorder::state_stopped != recorder->state())
+  if (Roan_trail::Kinetophone::Recorder::state_stopped != recorder->state())
   {
     Error_param e(false);
     recorder->stop(e); // ignore error
