@@ -1,6 +1,6 @@
 // Kinetophone_console_app.hpp
 //
-// Copyright 2011-2012 Roan Trail, Inc.
+// Copyright 2011-2013 Roan Trail, Inc.
 //
 // This file is part of Kinetophone.
 //
@@ -16,19 +16,22 @@
 // a copy of the GNU General Public License along with Kinetophone. If
 // not, see <http://www.gnu.org/licenses/>.
 
-#ifndef KINETOPHONE_CONSOLE_APP_HPP_
-#define KINETOPHONE_CONSOLE_APP_HPP_
+#ifndef ROAN_TRAIL_KINETOPHONE_APP_KINETOPHONE_CONSOLE_APP_HPP_
+#define ROAN_TRAIL_KINETOPHONE_APP_KINETOPHONE_CONSOLE_APP_HPP_
 
 #include "Console_app.hpp"
 #include <string>
 
 namespace Roan_trail
 {
-  class Error_param;
-
   namespace Kinetophone
   {
+    class Error_param;
     class Kinetophone_model;
+  }
+
+  namespace Kinetophone_app
+  {
     class Kinetophone_console_view;
     class Kinetophone_console_controller;
     class Kinetophone_console_config;
@@ -47,12 +50,12 @@ namespace Roan_trail
       bool mf_invariant(bool check_base_class = true) const;
     private:
       Kinetophone_console_config* const m_config;
-      Kinetophone_model* const m_model;
+      Roan_trail::Kinetophone::Kinetophone_model* const m_model;
       Kinetophone_console_controller* m_controller;
       Kinetophone_console_view* m_view;
       //
-      bool mf_record(Error_param& return_error);
-      bool mf_run_IO_loop(Error_param& return_error);
+      bool mf_record(Roan_trail::Kinetophone::Error_param& return_error);
+      bool mf_run_IO_loop(Roan_trail::Kinetophone::Error_param& return_error);
       // prevent compiler from generating
       Kinetophone_console_app(const Kinetophone_console_app& app);
       Kinetophone_console_app& operator=(const Kinetophone_console_app& app);
@@ -60,4 +63,4 @@ namespace Roan_trail
   }
 }
 
-#endif // KINETOPHONE_CONSOLE_APP_HPP_
+#endif // ROAN_TRAIL_KINETOPHONE_APP_KINETOPHONE_CONSOLE_APP_HPP_
