@@ -17,14 +17,14 @@
 // not, see <http://www.gnu.org/licenses/>.
 
 #include "Kinetophone_console_config.hpp"
-#include "../base/Sound_recorder_config.hpp"
-#include "../base/Sound_file_config.hpp"
-#include "../base/Level_meter_view.hpp"
-#include "../base/File_manager.hpp"
-#include "../base/option_checks.hpp"
-#include "../base/Option_validators.hpp"
-#include "../base/error/Boost_error.hpp"
-#include "../base/error/Kinetophone_error.hpp"
+#include <kinetophone/Sound_recorder_config.hpp>
+#include <kinetophone/Sound_file_config.hpp>
+#include <kinetophone/Level_meter_view.hpp>
+#include <kinetophone/File_manager.hpp>
+#include <kinetophone/option_checks.hpp>
+#include <kinetophone/Option_validators.hpp>
+#include <kinetophone/error/Boost_error.hpp>
+#include <kinetophone/error/Kinetophone_error.hpp>
 #include <boost/program_options.hpp>
 #include <exception>
 #include <fstream>
@@ -37,16 +37,20 @@ using std::ifstream;
 using std::logic_error;
 using std::string;
 using std::stringstream;
-using Roan_trail::File_manager;
-using Roan_trail::Options::check_conflicting_options;
-using Roan_trail::Options::check_option_dependency;
-using Roan_trail::Options::Directory_validator;
-using Roan_trail::Options::Fraction_validator;
-using Roan_trail::Options::Positive_int_validator;
-using Roan_trail::Options::Str_to_int_lookup_validator;
-using Roan_trail::Options::Validator;
-using Roan_trail::Recorder::Sound_file_config;
-using namespace Roan_trail::Kinetophone;
+using Roan_trail::Kinetophone::File_manager;
+using Roan_trail::Kinetophone::check_conflicting_options;
+using Roan_trail::Kinetophone::check_option_dependency;
+using Roan_trail::Kinetophone::Directory_validator;
+using Roan_trail::Kinetophone::Fraction_validator;
+using Roan_trail::Kinetophone::Level_meter_view;
+using Roan_trail::Kinetophone::Positive_int_validator;
+using Roan_trail::Kinetophone::Str_to_int_lookup_validator;
+using Roan_trail::Kinetophone::Validator;
+using Roan_trail::Kinetophone::Sound_file_config;
+using Roan_trail::Kinetophone::Boost_error;
+using Roan_trail::Kinetophone::Error_param;
+using Roan_trail::Kinetophone::Kinetophone_error;
+using namespace Roan_trail::Kinetophone_app;
 
 namespace PO = boost::program_options;
 
@@ -56,7 +60,7 @@ namespace PO = boost::program_options;
 
 namespace
 {
-  using Roan_trail::Recorder::Sound_recorder_config;
+  using Roan_trail::Kinetophone::Sound_recorder_config;
 
   //
   // some custom validation code for this configuration
@@ -576,7 +580,7 @@ int Kinetophone_console_config::parse_program_options(int argc,
     string diagnostic = e.what();
     stringstream s;
     s << "Reason: " << diagnostic << std::endl << std::endl;
-    s << "Enter kinetophone --help for valid program options.";
+    s << "Enter kinetophone_console --help for valid program options.";
     Kinetophone_error* error = new Kinetophone_error(error_location(),
                                                      Kinetophone_error::command_line,
                                                      new Boost_error(error_location(), s.str()));
