@@ -1,6 +1,6 @@
 // Kinetophone_console_config.hpp
 //
-// Copyright 2011-2012 Roan Trail, Inc.
+// Copyright 2011-2013 Roan Trail, Inc.
 //
 // This file is part of Kinetophone.
 //
@@ -16,21 +16,20 @@
 // a copy of the GNU General Public License along with Kinetophone. If
 // not, see <http://www.gnu.org/licenses/>.
 
-#ifndef KINETOPHONE_CONSOLE_CONFIG_HPP_
-#define KINETOPHONE_CONSOLE_CONFIG_HPP_
+#ifndef ROAN_TRAIL_KINETOPHONE_APP_KINETOPHONE_CONSOLE_CONFIG_HPP_
+#define ROAN_TRAIL_KINETOPHONE_APP_KINETOPHONE_CONSOLE_CONFIG_HPP_
 
 #include <string>
 
 namespace Roan_trail
 {
-  class Error_param;
-
-  namespace Recorder
+  namespace Kinetophone
   {
+    class Error_param;
     class Sound_recorder_config;
   }
 
-  namespace Kinetophone
+  namespace Kinetophone_app
   {
     // Helper struct to store console recorder application settings.
     // It is a struct instead of a class since it primarily only
@@ -65,7 +64,7 @@ namespace Roan_trail
       bool show_overflow_count;
       bool detailed_error;
       std::string custom_installation_dir;
-      Roan_trail::Recorder::Sound_recorder_config* sound_recorder_config;
+      Roan_trail::Kinetophone::Sound_recorder_config* sound_recorder_config;
       // defaults
       static const int default_update_rate;
       static const int default_level_meter_width;
@@ -78,9 +77,9 @@ namespace Roan_trail
       //
       int parse_program_options(int argc,
                                 const char** argv,
-                                Error_param& return_error);
+                                Roan_trail::Kinetophone::Error_param& return_error);
     };
   }
 }
 
-#endif // KINETOPHONE_CONSOLE_CONFIG_HPP_
+#endif // ROAN_TRAIL_KINETOPHONE_APP_KINETOPHONE_CONSOLE_CONFIG_HPP_
