@@ -1,6 +1,6 @@
 // Kinetophone_console_controller.cpp
 //
-// Copyright 2011-2012 Roan Trail, Inc.
+// Copyright 2011-2013 Roan Trail, Inc.
 //
 // This file is part of Kinetophone.
 //
@@ -17,16 +17,19 @@
 // not, see <http://www.gnu.org/licenses/>.
 
 #include "Kinetophone_console_controller.hpp"
-#include "../base/Kinetophone_model.hpp"
+#include <kinetophone/Kinetophone_model.hpp>
 #include "Kinetophone_console_view.hpp"
-#include "../base/Sound_recorder.hpp"
-#include "../base/Sound_recorder_config.hpp"
-#include "../base/Sound_file_config.hpp"
-#include "../base/error/Kinetophone_error.hpp"
+#include <kinetophone/Sound_recorder.hpp>
+#include <kinetophone/Sound_recorder_config.hpp>
+#include <kinetophone/Sound_file_config.hpp>
+#include <kinetophone/error/Kinetophone_error.hpp>
 #include <ncurses.h>
 
-using Roan_trail::Recorder::Sound_recorder;
-using namespace Roan_trail::Kinetophone;
+using Roan_trail::Kinetophone::Kinetophone_model;
+using Roan_trail::Kinetophone::Sound_recorder;
+using Roan_trail::Kinetophone::Error_param;
+using Roan_trail::Kinetophone::Kinetophone_error;
+using namespace Roan_trail::Kinetophone_app;
 
 //
 // Constructor/destructor/copy
@@ -116,7 +119,7 @@ bool Kinetophone_console_controller::process_input(bool& return_done, Error_para
     case 'q': // Quit
     case 'Q':
       // confirm stop while recording or paused
-      if (Roan_trail::Recorder::Recorder::state_stopped != state)
+      if (Roan_trail::Kinetophone::Recorder::state_stopped != state)
       {
         m_view.set_confirm_stop(true);
         m_quit_on_confirm = true;
@@ -128,7 +131,7 @@ bool Kinetophone_console_controller::process_input(bool& return_done, Error_para
       break;
     case 's': // Stop
     case 'S':
-      if (Roan_trail::Recorder::Recorder::state_stopped == state)
+      if (Roan_trail::Kinetophone::Recorder::state_stopped == state)
       {
         break;
       }
@@ -140,7 +143,7 @@ bool Kinetophone_console_controller::process_input(bool& return_done, Error_para
       break;
     case 'p': // Pause
     case 'P':
-      if (Roan_trail::Recorder::Recorder::state_recording != state)
+      if (Roan_trail::Kinetophone::Recorder::state_recording != state)
       {
         break;
       }
@@ -177,14 +180,14 @@ bool Kinetophone_console_controller::process_input(bool& return_done, Error_para
       break;
     case 'r': // Record
     case 'R':
-      if (Roan_trail::Recorder::Recorder::state_paused == state)
+      if (Roan_trail::Kinetophone::Recorder::state_paused == state)
       {
         command_completed = sound_recorder->record(error);
         on_error(!command_completed, new Kinetophone_error(error_location(),
                                                            Kinetophone_error::record,
                                                            error()));
       }
-      else if (Roan_trail::Recorder::Recorder::state_stopped == state)
+      else if (Roan_trail::Kinetophone::Recorder::state_stopped == state)
       {
         // see if we need to confirm overwrite (after first recording)
         if (sound_recorder->have_recording())
