@@ -1,6 +1,6 @@
 // Kinetophone_console_controller.hpp
 //
-// Copyright 2011 Roan Trail, Inc.
+// Copyright 2011, 2013 Roan Trail, Inc.
 //
 // This file is part of Kinetophone.
 //
@@ -16,32 +16,36 @@
 // a copy of the GNU General Public License along with Kinetophone. If
 // not, see <http://www.gnu.org/licenses/>.
 
-#ifndef KINETOPHONE_CONSOLE_CONTROLLER_HPP_
-#define KINETOPHONE_CONSOLE_CONTROLLER_HPP_
+#ifndef ROAN_TRAIL_KINETOPHONE_APP_KINETOPHONE_CONSOLE_CONTROLLER_HPP_
+#define ROAN_TRAIL_KINETOPHONE_APP_KINETOPHONE_CONSOLE_CONTROLLER_HPP_
 
 #include "Console_controller.hpp"
 
 namespace Roan_trail
 {
-  class Error_param;
-
   namespace Kinetophone
   {
+    class Error_param;
     class Kinetophone_model;
+  }
+
+  namespace Kinetophone_app
+  {
     class Kinetophone_console_view;
 
     class Kinetophone_console_controller : public Console_controller
     {
     public:
       // constructor/destructor/copy
-      Kinetophone_console_controller(Kinetophone_model& model, Kinetophone_console_view& view);
+      Kinetophone_console_controller(Roan_trail::Kinetophone::Kinetophone_model& model,
+                                     Kinetophone_console_view& view);
       //
-      virtual bool process_input(bool& return_done, Error_param& return_error);
+      virtual bool process_input(bool& return_done, Roan_trail::Kinetophone::Error_param& return_error);
     protected:
       // invariant check
       bool mf_invariant(bool check_base_class = true) const;
     private:
-      Kinetophone_model& m_model;
+      Roan_trail::Kinetophone::Kinetophone_model& m_model;
       Kinetophone_console_view& m_view;
       bool m_quit_on_confirm;
       //
@@ -53,4 +57,4 @@ namespace Roan_trail
   }
 }
 
-#endif // KINETOPHONE_CONSOLE_CONTROLLER_HPP_
+#endif // ROAN_TRAIL_KINETOPHONE_APP_KINETOPHONE_CONSOLE_CONTROLLER_HPP_
