@@ -1,6 +1,6 @@
 // Kinetophone_console_view.hpp
 //
-// Copyright 2011-2012 Roan Trail, Inc.
+// Copyright 2011-2013 Roan Trail, Inc.
 //
 // This file is part of Kinetophone.
 //
@@ -16,27 +16,31 @@
 // a copy of the GNU General Public License along with Kinetophone. If
 // not, see <http://www.gnu.org/licenses/>.
 
-#ifndef KINETOPHONE_CONSOLE_VIEW_HPP_
-#define KINETOPHONE_CONSOLE_VIEW_HPP_
+#ifndef ROAN_TRAIL_KINETOPHONE_APP_KINETOPHONE_CONSOLE_VIEW_HPP_
+#define ROAN_TRAIL_KINETOPHONE_APP_KINETOPHONE_CONSOLE_VIEW_HPP_
 
-#include "../base/View.hpp"
+#include <kinetophone/View.hpp>
 #include <string>
 #include <vector>
 
 namespace Roan_trail
 {
-  class Error_param;
-  class Console_level_meter_view;
-
   namespace Kinetophone
   {
+    class Error_param;
     class Kinetophone_model;
+  }
+
+  namespace Kinetophone_app
+  {
+    class Console_level_meter_view;
     class Kinetophone_console_config;
 
-    class Kinetophone_console_view : public View
+    class Kinetophone_console_view : public Roan_trail::Kinetophone::View
     {
     public:
-      Kinetophone_console_view(const Kinetophone_model& model, const Kinetophone_console_config& config);
+      Kinetophone_console_view(const Roan_trail::Kinetophone::Kinetophone_model& model,
+                               const Kinetophone_console_config& config);
       ~Kinetophone_console_view();
       // accessors
       bool confirm_overwrite() const { return m_confirm_overwrite; }
@@ -49,18 +53,18 @@ namespace Roan_trail
       void set_confirm_stop(bool confirm) { m_confirm_stop = confirm; }
       void set_level_meter_peak_mode(bool peak_mode);
       // view update
-      virtual bool update(Error_param& return_error);
+      virtual bool update(Roan_trail::Kinetophone::Error_param& return_error);
       // commands
       void clear();
       // commands (class member functions)
       static void output(const std::string& message);
       static void output_error(const std::string& message);
-      static bool list_devices(Error_param& return_error);
+      static bool list_devices(Roan_trail::Kinetophone::Error_param& return_error);
     protected:
       // invariant check
       bool mf_invariant(bool check_base_class = true) const;
     private:
-      const Kinetophone_model& m_model;
+      const Roan_trail::Kinetophone::Kinetophone_model& m_model;
       const Kinetophone_console_config& m_config;
       Console_level_meter_view* m_level_meter_view;
       int m_console_width;
@@ -89,4 +93,4 @@ namespace Roan_trail
   }
 }
 
-#endif // KINETOPHONE_CONSOLE_VIEW_HPP_
+#endif // ROAN_TRAIL_KINETOPHONE_APP_KINETOPHONE_CONSOLE_VIEW_HPP_
