@@ -1,6 +1,6 @@
 // Kinetophone_dbus_client_recorder.cpp
 //
-// Copyright 2011-2012 Roan Trail, Inc.
+// Copyright 2011-2013 Roan Trail, Inc.
 //
 // This file is part of Kinetophone.
 //
@@ -17,12 +17,12 @@
 // not, see <http://www.gnu.org/licenses/>.
 
 #include "Kinetophone_dbus_client_recorder.hpp"
-#include "../base/common.hpp"
+#include <kinetophone/common.hpp>
 #include <dbus-c++/dbus.h>
 
 using DBus::Connection;
 
-using namespace Roan_trail::Kinetophone;
+using namespace Roan_trail::Kinetophone_app;
 
 //
 // Constructor, destructor
