@@ -1,6 +1,6 @@
 // Kinetophone_dbus_client_recorder.hpp
 //
-// Copyright 2011-2012 Roan Trail, Inc.
+// Copyright 2011-2013 Roan Trail, Inc.
 //
 // This file is part of Kinetophone.
 //
@@ -16,15 +16,16 @@
 // a copy of the GNU General Public License along with Kinetophone. If
 // not, see <http://www.gnu.org/licenses/>.
 
-#ifndef KINETOPHONE_DBUS_CLIENT_RECORDER_HPP_
-#define KINETOPHONE_DBUS_CLIENT_RECORDER_HPP_
+#ifndef ROAN_TRAIL_KINETOPHONE_APP_KINETOPHONE_DBUS_CLIENT_RECORDER_HPP_
+#define ROAN_TRAIL_KINETOPHONE_APP_KINETOPHONE_DBUS_CLIENT_RECORDER_HPP_
 
 #include <dbus-c++/dbus.h>
 #include "Kinetophone_dbus_client_glue.hpp"
 
 namespace Roan_trail
 {
-  namespace Kinetophone {
+  namespace Kinetophone_app
+  {
     class Kinetophone_dbus_client_recorder
       : public com::roantrail::dbus::kinetophone::recorder_proxy,
         public DBus::IntrospectableProxy,
@@ -45,5 +46,4 @@ namespace Roan_trail
   }
 }
 
-#endif // KINETOPHONE_DBUS_CLIENT_RECORDER_HPP_
-
+#endif // ROAN_TRAIL_KINETOPHONE_APP_KINETOPHONE_DBUS_CLIENT_RECORDER_HPP_
