@@ -1,6 +1,6 @@
 // Kinetophone_dbus_recorder.cpp
 //
-// Copyright 2011-2012 Roan Trail, Inc.
+// Copyright 2011-2013 Roan Trail, Inc.
 //
 // This file is part of Kinetophone.
 //
@@ -18,12 +18,13 @@
 
 #include "Kinetophone_dbus_recorder.hpp"
 #include "Kinetophone_dbus_server_glue.hpp"
-#include "../base/Sound_recorder_config.hpp"
-#include "../base/Sound_file_config.hpp"
-#include "../base/Device_enum.hpp"
-#include "../base/Segment.hpp"
-#include "../base/error/Kinetophone_error.hpp"
-#include "../base/error/Record_error.hpp"
+#include <kinetophone/Narration_recorder.hpp>
+#include <kinetophone/Sound_recorder_config.hpp>
+#include <kinetophone/Sound_file_config.hpp>
+#include <kinetophone/Device_enum.hpp>
+#include <kinetophone/Segment.hpp>
+#include <kinetophone/error/Kinetophone_error.hpp>
+#include <kinetophone/error/Record_error.hpp>
 #include <libxml++/document.h>
 #include <libxml++/exceptions/exception.h>
 #include <libxml++/nodes/node.h>
@@ -41,13 +42,16 @@ using std::endl;
 using std::string;
 using std::map;
 using std::vector;
-using Roan_trail::Long_int;
-using Roan_trail::Error;
-using Roan_trail::Recorder::Segment;
-using Roan_trail::Recorder::Record_error;
-using Roan_trail::Recorder::Sound_recorder_config;
-using Roan_trail::Recorder::Device_enum;
-using namespace Roan_trail::Kinetophone;
+using Roan_trail::Kinetophone::Device_enum;
+using Roan_trail::Kinetophone::Long_int;
+using Roan_trail::Kinetophone::Narration_recorder;
+using Roan_trail::Kinetophone::Segment;
+using Roan_trail::Kinetophone::Record_error;
+using Roan_trail::Kinetophone::Sound_recorder_config;
+using Roan_trail::Kinetophone::Error;
+using Roan_trail::Kinetophone::Error_param;
+using Roan_trail::Kinetophone::Kinetophone_error;
+using namespace Roan_trail::Kinetophone_app;
 
 //
 // Internal helpers
