@@ -1,6 +1,6 @@
 // Kinetophone_dbus_recorder.hpp
 //
-// Copyright 2011-2012 Roan Trail, Inc.
+// Copyright 2011-2013 Roan Trail, Inc.
 //
 // This file is part of Kinetophone.
 //
@@ -16,28 +16,28 @@
 // a copy of the GNU General Public License along with Kinetophone. If
 // not, see <http://www.gnu.org/licenses/>.
 
-#ifndef KINETOPHONE_DBUS_RECORDER_HPP_
-#define KINETOPHONE_DBUS_RECORDER_HPP_
+#ifndef ROAN_TRAIL_KINETOPHONE_APP_KINETOPHONE_DBUS_RECORDER_HPP_
+#define ROAN_TRAIL_KINETOPHONE_APP_KINETOPHONE_DBUS_RECORDER_HPP_
 
 #include <dbus-c++/dbus.h>
 #include "Kinetophone_dbus_server_glue.hpp"
-#include "../base/common.hpp"
-#include "../base/Narration_recorder.hpp"
+#include <kinetophone/common.hpp>
+#include <kinetophone/Narration_recorder.hpp>
 #include <string>
 #include <vector>
 #include <map>
 
 namespace Roan_trail
 {
-  typedef std::map<std::string, std::string> Error_dictionary;
-
-  namespace Kinetophone
+  namespace Kinetophone_app
   {
+    typedef std::map<std::string, std::string> Error_dictionary;
+
     class Kinetophone_dbus_recorder
       : public com::roantrail::dbus::kinetophone::recorder_adaptor,
         public DBus::IntrospectableAdaptor,
         public DBus::ObjectAdaptor,
-        public Roan_trail::Recorder::Narration_recorder
+        public Roan_trail::Kinetophone::Narration_recorder
     {
     public:
       // constructor, destructor
@@ -46,7 +46,7 @@ namespace Roan_trail
       void remove(bool& return_have_error, Error_dictionary& return_error);
       // helpers
       static const std::string& dbus_name();
-      static std::string dbus_path(Long_int ID);
+      static std::string dbus_path(Roan_trail::Kinetophone::Long_int ID);
       //
       // DBUS interface
       //   control
@@ -132,4 +132,4 @@ namespace Roan_trail
   }
 }
 
-#endif // KINETOPHONE_DBUS_RECORDER_HPP_
+#endif // ROAN_TRAIL_KINETOPHONE_APP_KINETOPHONE_DBUS_RECORDER_HPP_
