@@ -1,6 +1,6 @@
 // Fraction_bar_widget.cpp
 //
-// Copyright 2011-2012 Roan Trail, Inc.
+// Copyright 2011-2013 Roan Trail, Inc.
 //
 // This file is part of Kinetophone.
 //
@@ -23,8 +23,8 @@
 #include <gdkmm/general.h>
 #include <gtkmm/container.h>
 
-#include "../base/common.hpp"
-#include "../base/error/Error.hpp"
+#include <kinetophone/common.hpp>
+#include <kinetophone/error/Error.hpp>
 #include <iostream>
 #include <cstring>
 
@@ -35,9 +35,9 @@ using Gtk::Requisition;
 using Gtk::Widget;
 using Gdk::Rectangle;
 using Gdk::Window;
-using Roan_trail::Error_param;
+using Roan_trail::Kinetophone::Error_param;
 using namespace Gdk::Cairo;
-using namespace Roan_trail::Kinetophone;
+using namespace Roan_trail::Kinetophone_app;
 
 namespace
 {
