@@ -1,6 +1,6 @@
 // Kinetophone_narrator_app.hpp
 //
-// Copyright 2011-2012 Roan Trail, Inc.
+// Copyright 2011-2013 Roan Trail, Inc.
 //
 // This file is part of Kinetophone.
 //
@@ -16,24 +16,27 @@
 // a copy of the GNU General Public License along with Kinetophone. If
 // not, see <http://www.gnu.org/licenses/>.
 
-#ifndef KINETOPHONE_NARRATOR_APP_HPP_
-#define KINETOPHONE_NARRATOR_APP_HPP_
+#ifndef ROAN_TRAIL_KINETOPHONE_APP_KINETOPHONE_NARRATOR_APP_HPP_
+#define ROAN_TRAIL_KINETOPHONE_APP_KINETOPHONE_NARRATOR_APP_HPP_
 
-#include "../base/Application.hpp"
+#include <kinetophone/Application.hpp>
 #include <string>
 
 namespace Roan_trail
 {
-  class Error_param;
-
   namespace Kinetophone
+  {
+    class Error_param;
+  }
+
+  namespace Kinetophone_app
   {
     class Kinetophone_narrator_config;
     class Kinetophone_narrator_model;
     class Kinetophone_narrator_controller;
     class Kinetophone_narrator_view;
 
-    class Kinetophone_narrator_app : public Application
+    class Kinetophone_narrator_app : public Roan_trail::Kinetophone::Application
     {
     public:
       // Constructor/destructor/copy
@@ -51,8 +54,8 @@ namespace Roan_trail
       //
       void mf_connect_signals(Kinetophone_narrator_controller& controller,
                               Kinetophone_narrator_view& view);
-      bool mf_narrate(Error_param& return_error);
-      bool mf_run_GUI(Error_param& return_error);
+      bool mf_narrate(Roan_trail::Kinetophone::Error_param& return_error);
+      bool mf_run_GUI(Roan_trail::Kinetophone::Error_param& return_error);
       // prevent compiler from generating
       Kinetophone_narrator_app(const Kinetophone_narrator_app& app);
       Kinetophone_narrator_app& operator=(const Kinetophone_narrator_app& app);
