@@ -1,6 +1,6 @@
 // Kinetophone_narrator_config.cpp
 //
-// Copyright 2011-2013 Roan Trail, Inc.
+// Copyright 2011-2014 Roan Trail, Inc.
 //
 // This file is part of Kinetophone.
 //
@@ -17,16 +17,16 @@
 // not, see <http://www.gnu.org/licenses/>.
 
 #include "Kinetophone_narrator_config.hpp"
-#include "../base/common.hpp"
-#include "../base/File_manager.hpp"
-#include "../base/Image_types.hpp"
-#include "../base/Level_meter_view.hpp"
-#include "../base/option_checks.hpp"
-#include "../base/Option_validators.hpp"
-#include "../base/Sound_file_config.hpp"
-#include "../base/Sound_recorder_config.hpp"
-#include "../base/error/Boost_error.hpp"
-#include "../base/error/Kinetophone_error.hpp"
+#include <kinetophone/common.hpp>
+#include <kinetophone/File_manager.hpp>
+#include <kinetophone/Image_types.hpp>
+#include <kinetophone/Level_meter_view.hpp>
+#include <kinetophone/option_checks.hpp>
+#include <kinetophone/Option_validators.hpp>
+#include <kinetophone/Sound_file_config.hpp>
+#include <kinetophone/Sound_recorder_config.hpp>
+#include <kinetophone/error/Boost_error.hpp>
+#include <kinetophone/error/Kinetophone_error.hpp>
 #include <boost/program_options.hpp>
 #include <exception>
 #include <fstream>
@@ -40,18 +40,23 @@ using std::ifstream;
 using std::logic_error;
 using std::string;
 using std::stringstream;
-using Roan_trail::Color;
-using Roan_trail::File_manager;
-using Roan_trail::Options::check_conflicting_options;
-using Roan_trail::Options::check_option_dependency;
-using Roan_trail::Options::Color_validator;
-using Roan_trail::Options::Directory_validator;
-using Roan_trail::Options::Fraction_validator;
-using Roan_trail::Options::Positive_int_validator;
-using Roan_trail::Options::Str_to_int_lookup_validator;
-using Roan_trail::Options::Validator;
-using Roan_trail::Recorder::Sound_file_config;
-using namespace Roan_trail::Kinetophone;
+using Roan_trail::Kinetophone::Color;
+using Roan_trail::Kinetophone::File_manager;
+using Roan_trail::Kinetophone::check_conflicting_options;
+using Roan_trail::Kinetophone::check_option_dependency;
+using Roan_trail::Kinetophone::Color_validator;
+using Roan_trail::Kinetophone::Directory_validator;
+using Roan_trail::Kinetophone::Fraction_validator;
+using Roan_trail::Kinetophone::Level_meter_view;
+using Roan_trail::Kinetophone::Positive_int_validator;
+using Roan_trail::Kinetophone::Sound_file_config;
+using Roan_trail::Kinetophone::Sound_recorder_config;
+using Roan_trail::Kinetophone::Str_to_int_lookup_validator;
+using Roan_trail::Kinetophone::Validator;
+using Roan_trail::Kinetophone::Boost_error;
+using Roan_trail::Kinetophone::Error_param;
+using Roan_trail::Kinetophone::Kinetophone_error;
+using namespace Roan_trail::Kinetophone_app;
 
 namespace PO = boost::program_options;
 
@@ -61,8 +66,6 @@ namespace PO = boost::program_options;
 
 namespace
 {
-  using Roan_trail::Recorder::Sound_recorder_config;
-
   //
   // some custom validation code for this configuration
   //
@@ -426,7 +429,7 @@ namespace
        "set number of times display is refreshed per second (must be > 0)")
       ("level-meter-ballistics,B", PO::value<Validator<bool> >(&return_v.level_meter.model_ballistics)
        ->implicit_value(Validator<bool>(return_v.level_meter.model_ballistics)),
-       "model ballistics in level meter (requires --level-meter or -m)")
+       "model ballistics in level meter")
       ("level-meter-attack-period,P", PO::value<Positive_int_validator>(&return_v.level_meter.attack_period)
        ->default_value(return_v.level_meter.attack_period),
        "set the number of milliseconds for the level meter to travel forward 0.99X full scale (must be > 0, "
