@@ -1,6 +1,6 @@
 // Kinetophone_narrator_controller.cpp
 //
-// Copyright 2011-2012 Roan Trail, Inc.
+// Copyright 2011-2013 Roan Trail, Inc.
 //
 // This file is part of Kinetophone.
 //
@@ -23,14 +23,15 @@
 #include <gtkmm/main.h>
 #include <gdkmm/pixbuf.h>
 
+#include <kinetophone/common.hpp>
 #include "Kinetophone_narrator_model.hpp"
 #include "Kinetophone_narrator_view.hpp"
 #include "Kinetophone_narrator_config.hpp"
-#include "../base/Narration_recorder.hpp"
-#include "../base/Slide_collection.hpp"
-#include "../base/Sound_recorder_config.hpp"
-#include "../base/Sound_file_config.hpp"
-#include "../base/error/Kinetophone_error.hpp"
+#include <kinetophone/Narration_recorder.hpp>
+#include <kinetophone/Slide_collection.hpp>
+#include <kinetophone/Sound_recorder_config.hpp>
+#include <kinetophone/Sound_file_config.hpp>
+#include <kinetophone/error/Kinetophone_error.hpp>
 #include <string>
 #include <sstream>
 #include <iomanip>
@@ -42,9 +43,13 @@ using std::endl;
 using std::string;
 using std::stringstream;
 using sigc::mem_fun;
-using Roan_trail::Recorder::Narration_recorder;
-using Roan_trail::Source::Slide_collection;
-using namespace Roan_trail::Kinetophone;
+using Roan_trail::Kinetophone::min;
+using Roan_trail::Kinetophone::Narration_recorder;
+using Roan_trail::Kinetophone::Slide_collection;
+using Roan_trail::Kinetophone::Error;
+using Roan_trail::Kinetophone::Error_param;
+using Roan_trail::Kinetophone::Kinetophone_error;
+using namespace Roan_trail::Kinetophone_app;
 
 //
 // Constructor/destructor/copy
@@ -118,7 +123,7 @@ void Kinetophone_narrator_controller::setup()
 void Kinetophone_narrator_controller::retake()
 {
   Narration_recorder* recorder = m_model.narration_recorder();
-  if (Roan_trail::Recorder::Recorder::state_recording == recorder->state())
+  if (Roan_trail::Kinetophone::Recorder::state_recording == recorder->state())
   {
     Error_param error;
     recorder->retake(error);
@@ -135,7 +140,7 @@ void Kinetophone_narrator_controller::previous()
   m_signal_model_slides_will_update.emit();
 
   Narration_recorder* recorder = m_model.narration_recorder();
-  if (Roan_trail::Recorder::Recorder::state_recording == recorder->state())
+  if (Roan_trail::Kinetophone::Recorder::state_recording == recorder->state())
   {
     m_model.slides()->previous_slide();
     Error_param error;
@@ -160,7 +165,7 @@ void Kinetophone_narrator_controller::slide(int slide_index)
 
   Slide_collection<RefPtr<Pixbuf> >* slides = m_model.slides();
   Narration_recorder* recorder = m_model.narration_recorder();
-  if (Roan_trail::Recorder::Recorder::state_recording == recorder->state())
+  if (Roan_trail::Kinetophone::Recorder::state_recording == recorder->state())
   {
     slides->set_current_slide_index(slide_index);
     Error_param error;
@@ -184,7 +189,7 @@ void Kinetophone_narrator_controller::next()
   m_signal_model_slides_will_update.emit();
 
   Narration_recorder* recorder = m_model.narration_recorder();
-  if (Roan_trail::Recorder::Recorder::state_recording == recorder->state())
+  if (Roan_trail::Kinetophone::Recorder::state_recording == recorder->state())
   {
     m_model.slides()->next_slide();
     Error_param error;
@@ -209,7 +214,7 @@ void Kinetophone_narrator_controller::thumbnail_choose(int slide_index)
 
   Slide_collection<RefPtr<Pixbuf> >* slides = m_model.slides();
   Narration_recorder* recorder = m_model.narration_recorder();
-  if (Roan_trail::Recorder::Recorder::state_recording == recorder->state())
+  if (Roan_trail::Kinetophone::Recorder::state_recording == recorder->state())
   {
     slides->set_current_slide_index(slide_index);
     Error_param error;
@@ -251,7 +256,7 @@ void Kinetophone_narrator_controller::record()
   m_signal_model_recorder_will_update.emit();
 
   Narration_recorder* recorder = m_model.narration_recorder();
-  if (Roan_trail::Recorder::Recorder::state_stopped == recorder->state())
+  if (Roan_trail::Kinetophone::Recorder::state_stopped == recorder->state())
   {
     if (recorder->have_recording())
     {
@@ -323,14 +328,14 @@ void Kinetophone_narrator_controller::pause()
 
   Narration_recorder* recorder = m_model.narration_recorder();
   Error_param error;
-  if (Roan_trail::Recorder::Recorder::state_recording == recorder->state())
+  if (Roan_trail::Kinetophone::Recorder::state_recording == recorder->state())
   {
     bool recording_paused = recorder->pause(error);
     on_error(!recording_paused, new Kinetophone_error(error_location(),
                                                       Kinetophone_error::record,
                                                       error()));
   }
-  else if (Roan_trail::Recorder::Recorder::state_paused == recorder->state())
+  else if (Roan_trail::Kinetophone::Recorder::state_paused == recorder->state())
   {
     bool recording_resumed = recorder->record(m_model.slides()->current_slide_index(), error);
     on_error(!recording_resumed, new Kinetophone_error(error_location(),
@@ -414,7 +419,7 @@ void Kinetophone_narrator_controller::notes_editing_done(const string &current_n
 
 void Kinetophone_narrator_controller::export_session(const string& session_file)
 {
-  precondition((Roan_trail::Recorder::Recorder::state_stopped == m_model.narration_recorder()->state())
+  precondition((Roan_trail::Kinetophone::Recorder::state_stopped == m_model.narration_recorder()->state())
                && mf_invariant());
 
   start_error_block();
@@ -535,11 +540,11 @@ bool Kinetophone_narrator_controller::mf_update_tick()
   // update time display
   if (!(m_update_tick_count % m_update_period_for_record))
   {
-    if (Roan_trail::Recorder::Recorder::state_recording == recorder_state)
+    if (Roan_trail::Kinetophone::Recorder::state_recording == recorder_state)
     {
       m_signal_update_time.emit(false);
     }
-    else if (Roan_trail::Recorder::Recorder::state_paused == recorder_state)
+    else if (Roan_trail::Kinetophone::Recorder::state_paused == recorder_state)
     {
       if (!(m_update_tick_count % m_time_update_period_for_pause))
       {
@@ -549,7 +554,7 @@ bool Kinetophone_narrator_controller::mf_update_tick()
   }
 
   // update available space
-  if (Roan_trail::Recorder::Recorder::state_recording == recorder_state)
+  if (Roan_trail::Kinetophone::Recorder::state_recording == recorder_state)
   {
     if (!(m_update_tick_count % m_update_period_for_record))
     {
@@ -571,7 +576,7 @@ bool Kinetophone_narrator_controller::mf_update_tick()
   }
 
   // check for an record error between updates, if recording
-  if (Roan_trail::Recorder::Recorder::state_recording == recorder_state)
+  if (Roan_trail::Kinetophone::Recorder::state_recording == recorder_state)
   {
     const Error* record_error = recorder->record_error();
     if (record_error)
