@@ -1,6 +1,6 @@
 // Kinetophone_narrator_controller.hpp
 //
-// Copyright 2011-2012 Roan Trail, Inc.
+// Copyright 2011-2013 Roan Trail, Inc.
 //
 // This file is part of Kinetophone.
 //
@@ -16,18 +16,21 @@
 // a copy of the GNU General Public License along with Kinetophone. If
 // not, see <http://www.gnu.org/licenses/>.
 
-#ifndef KINETOPHONE_NARRATOR_CONTROLLER_HPP_
-#define KINETOPHONE_NARRATOR_CONTROLLER_HPP_
+#ifndef ROAN_TRAIL_KINETOPHONE_APP_KINETOPHONE_NARRATOR_CONTROLLER_HPP_
+#define ROAN_TRAIL_KINETOPHONE_APP_KINETOPHONE_NARRATOR_CONTROLLER_HPP_
 
-#include "../base/common.hpp"
+#include <kinetophone/common.hpp>
 #include <string>
 #include <sigc++/sigc++.h>
 
 namespace Roan_trail
 {
-  class Error;
-
   namespace Kinetophone
+  {
+    class Error;
+  }
+
+  namespace Kinetophone_app
   {
     class Kinetophone_narrator_model;
     struct Kinetophone_narrator_config;
@@ -55,7 +58,7 @@ namespace Roan_trail
       sigc::signal<void>& signal_reset_clipped() { return m_signal_reset_clipped; }
       sigc::signal<bool>& signal_overwrite_recording() { return m_signal_overwrite_recording; }
       sigc::signal<void, const std::string&>& signal_session_info() { return m_signal_session_info; }
-      sigc::signal<int, const Error&, bool>& signal_error() { return m_signal_error; }
+      sigc::signal<int, const Roan_trail::Kinetophone::Error&, bool>& signal_error() { return m_signal_error; }
       // slots
       void retake();
       void previous();
@@ -79,7 +82,7 @@ namespace Roan_trail
       Kinetophone_narrator_model& m_model;
       Kinetophone_narrator_config& m_config;
       int m_update_rate;
-      Long_int m_update_tick_count;
+      Roan_trail::Kinetophone::Long_int m_update_tick_count;
       int m_update_period_for_record;
       int m_time_update_period_for_pause;
       int m_flash_period_for_pause;
@@ -101,7 +104,7 @@ namespace Roan_trail
       sigc::signal<void> m_signal_reset_clipped;
       sigc::signal<bool> m_signal_overwrite_recording;
       sigc::signal<void, const std::string&> m_signal_session_info;
-      sigc::signal<int, const Error&, bool> m_signal_error;
+      sigc::signal<int, const Roan_trail::Kinetophone::Error&, bool> m_signal_error;
       // connections
       sigc::connection m_update_tick_connection;
       //
@@ -110,7 +113,7 @@ namespace Roan_trail
       // update
       void mf_initial_update();
       bool mf_update_tick();
-      void mf_update_available_space(Long_int& return_bytes_available);
+      void mf_update_available_space(Roan_trail::Kinetophone::Long_int& return_bytes_available);
       // prevent compiler from generating
       Kinetophone_narrator_controller(const Kinetophone_narrator_controller& c);
       Kinetophone_narrator_controller& operator=(const Kinetophone_narrator_controller& c);
@@ -118,4 +121,4 @@ namespace Roan_trail
   }
 }
 
-#endif // KINETOPHONE_NARRATOR_CONTROLLER_HPP_
+#endif // ROAN_TRAIL_KINETOPHONE_APP_KINETOPHONE_NARRATOR_CONTROLLER_HPP_
