@@ -1,6 +1,6 @@
 // Kinetophone_narrator_error_dialog.cpp
 //
-// Copyright 2011-2012 Roan Trail, Inc.
+// Copyright 2011-2013 Roan Trail, Inc.
 //
 // This file is part of Kinetophone.
 //
@@ -29,8 +29,8 @@
 #include <gtkmm/label.h>
 #include <gtkmm/stock.h>
 
-#include "../base/common.hpp"
-#include "../base/error/Error.hpp"
+#include <kinetophone/common.hpp>
+#include <kinetophone/error/Error.hpp>
 #include <string>
 
 using Gtk::Alignment;
@@ -41,7 +41,8 @@ using Gtk::Image;
 using Gtk::Label;
 using Gtk::VBox;
 using std::string;
-using namespace Roan_trail::Kinetophone;
+using Roan_trail::Kinetophone::Error;
+using namespace Roan_trail::Kinetophone_app;
 
 //
 // Internal constants
