@@ -1,6 +1,6 @@
 // Kinetophone_narrator_error_dialog.hpp
 //
-// Copyright 2011-2012 Roan Trail, Inc.
+// Copyright 2011-2013 Roan Trail, Inc.
 //
 // This file is part of Kinetophone.
 //
@@ -16,22 +16,25 @@
 // a copy of the GNU General Public License along with Kinetophone. If
 // not, see <http://www.gnu.org/licenses/>.
 
-#ifndef KINETOPHONE_NARRATOR_ERROR_DIALOG_HPP_
-#define KINETOPHONE_NARRATOR_ERROR_DIALOG_HPP_
+#ifndef ROAN_TRAIL_KINETOPHONE_APP_KINETOPHONE_NARRATOR_ERROR_DIALOG_HPP_
+#define ROAN_TRAIL_KINETOPHONE_APP_KINETOPHONE_NARRATOR_ERROR_DIALOG_HPP_
 
 #include <gtkmm/dialog.h>
 
 namespace Roan_trail
 {
-  class Error;
-
   namespace Kinetophone
+  {
+    class Error;
+  }
+
+  namespace Kinetophone_app
   {
     class Kinetophone_narrator_error_dialog : public Gtk::Dialog
     {
     public:
       // constructor/destructor
-      Kinetophone_narrator_error_dialog(const Error& dialog_error,
+      Kinetophone_narrator_error_dialog(const Roan_trail::Kinetophone::Error& dialog_error,
                                         Window& parent,
                                         bool is_warning = false);
       virtual ~Kinetophone_narrator_error_dialog();
@@ -39,7 +42,7 @@ namespace Roan_trail
       // invariant check
       bool mf_invariant(bool check_base_class = true) const;
     private:
-      void mf_setup_widgets(const Error& dialog_eror, bool is_warning);
+      void mf_setup_widgets(const Roan_trail::Kinetophone::Error& dialog_eror, bool is_warning);
       // prevent compiler from generating
       Kinetophone_narrator_error_dialog(const Kinetophone_narrator_error_dialog& level_meter);
       Kinetophone_narrator_error_dialog& operator=(const Kinetophone_narrator_error_dialog& level_meter);
@@ -47,4 +50,4 @@ namespace Roan_trail
   }
 }
 
-#endif // KINETOPHONE_NARRATOR_ERROR_DIALOG_HPP_
+#endif // ROAN_TRAIL_KINETOPHONE_APP_KINETOPHONE_NARRATOR_ERROR_DIALOG_HPP_
