@@ -1,6 +1,6 @@
 // Kinetophone_narrator_view.cpp
 //
-// Copyright 2011-2012 Roan Trail, Inc.
+// Copyright 2011-2013 Roan Trail, Inc.
 //
 // This file is part of Kinetophone.
 //
@@ -33,22 +33,22 @@
 #include <gtkmm/textview.h>
 #include <gtkmm/togglebutton.h>
 #include <gtkmm/toggletoolbutton.h>
-
+#include <kinetophone/common.hpp>
 #include "Kinetophone_narrator_model.hpp"
 #include "Kinetophone_narrator_config.hpp"
 #include "Kinetophone_narrator_window.hpp"
 #include "Kinetophone_narrator_error_dialog.hpp"
-#include "../base/Narration_recorder.hpp"
-#include "../base/Slide_collection.hpp"
-#include "../base/Sound_recorder_config.hpp"
-#include "../base/Sound_file_config.hpp"
+#include <kinetophone/Narration_recorder.hpp>
+#include <kinetophone/Slide_collection.hpp>
+#include <kinetophone/Sound_recorder_config.hpp>
+#include <kinetophone/Sound_file_config.hpp>
 #include "Level_meter_widget.hpp"
 #include "Fraction_bar_widget.hpp"
 #include "Scaled_image_widget.hpp"
-#include "../base/Slide_collection.hpp"
-#include "../base/Device_enum.hpp"
-#include "../base/error/Kinetophone_error.hpp"
-#include "../base/error/Curses_error.hpp"
+#include <kinetophone/Slide_collection.hpp>
+#include <kinetophone/Device_enum.hpp>
+#include <kinetophone/error/Kinetophone_error.hpp>
+#include <kinetophone/error/Curses_error.hpp>
 #include <iostream>
 #include <iomanip>
 #include <sstream>
@@ -91,12 +91,17 @@ using std::vector;
 using sigc::bind;
 using sigc::connection;
 using sigc::mem_fun;
-using Roan_trail::Error_param;
-using Roan_trail::Source::Slide_collection;
-using Roan_trail::Recorder::Device_enum;
-using Roan_trail::Recorder::Narration_recorder;
-using Roan_trail::Recorder::Sound_recorder_config;
-using namespace Roan_trail::Kinetophone;
+using Roan_trail::Kinetophone::Error_param;
+using Roan_trail::Kinetophone::Slide_collection;
+using Roan_trail::Kinetophone::Device_enum;
+using Roan_trail::Kinetophone::Long_int;
+using Roan_trail::Kinetophone::min;
+using Roan_trail::Kinetophone::Narration_recorder;
+using Roan_trail::Kinetophone::Rect_size;
+using Roan_trail::Kinetophone::Sound_recorder_config;
+using Roan_trail::Kinetophone::Error;
+using Roan_trail::Kinetophone::Kinetophone_error;
+using namespace Roan_trail::Kinetophone_app;
 
 //
 // Internal variables
@@ -165,7 +170,7 @@ void Kinetophone_narrator_view::model_slides_will_update()
   precondition(mf_invariant());
 
   const Narration_recorder* recorder = m_model.narration_recorder();
-  if (Roan_trail::Recorder::Recorder::state_stopped == recorder->state())
+  if (Roan_trail::Kinetophone::Recorder::state_stopped == recorder->state())
   {
     mf_notes_editing_done();
   }
@@ -187,7 +192,7 @@ void Kinetophone_narrator_view::model_recorder_will_update()
   precondition(mf_invariant());
 
   const Narration_recorder* recorder = m_model.narration_recorder();
-  if (Roan_trail::Recorder::Recorder::state_stopped == recorder->state())
+  if (Roan_trail::Kinetophone::Recorder::state_stopped == recorder->state())
   {
     mf_notes_editing_done();
   }
@@ -252,7 +257,7 @@ void Kinetophone_narrator_view::model_recorder_updated()
   // TODO: make sure the "gtk-*" icons are available for install
 
   const int recorder_state = recorder->state();
-  if (Roan_trail::Recorder::Recorder::state_stopped == recorder_state)
+  if (Roan_trail::Kinetophone::Recorder::state_stopped == recorder_state)
   {
     // menu
     m_main_window->file_export_session_menu_item()->set_sensitive();
@@ -276,13 +281,13 @@ void Kinetophone_narrator_view::model_recorder_updated()
     // notes
     m_main_window->notes_text_view()->set_editable();
   }
-  else if (Roan_trail::Recorder::Recorder::state_paused == recorder_state)
+  else if (Roan_trail::Kinetophone::Recorder::state_paused == recorder_state)
   {
     // buttons
     m_main_window->retake_tool_button()->set_sensitive(false);
     m_main_window->pause_toggle_tool_button()->set_sensitive();
   }
-  else if (Roan_trail::Recorder::Recorder::state_recording == recorder_state)
+  else if (Roan_trail::Kinetophone::Recorder::state_recording == recorder_state)
   {
     // menu
     m_main_window->file_export_session_menu_item()->set_sensitive(false);
@@ -428,7 +433,7 @@ void Kinetophone_narrator_view::update_time(bool is_flashing)
                    iv_ignore_error);
 
   stringstream record_time;
-  if (Roan_trail::Recorder::Recorder::state_stopped == recorder->state())
+  if (Roan_trail::Kinetophone::Recorder::state_stopped == recorder->state())
   {
     record_time << "Total: ";
     if (!recorder->have_recording())
@@ -897,7 +902,7 @@ void Kinetophone_narrator_view::mf_mute()
 void Kinetophone_narrator_view::mf_notes_changed()
 {
   const Narration_recorder* recorder = m_model.narration_recorder();
-  if (Roan_trail::Recorder::Recorder::state_stopped == recorder->state())
+  if (Roan_trail::Kinetophone::Recorder::state_stopped == recorder->state())
   {
     m_main_window->notes_editing_done_button()->show();
     m_notes_changed_signal.emit();
@@ -944,7 +949,7 @@ bool Kinetophone_narrator_view::mf_delete_main_window(GdkEventAny* event)
 
   // don't allow window delete if recording
   const Narration_recorder* recorder = m_model.narration_recorder();
-  if (Roan_trail::Recorder::Recorder::state_stopped == recorder->state())
+  if (Roan_trail::Kinetophone::Recorder::state_stopped == recorder->state())
   {
     return_value = !mf_verify_quit();
   }
@@ -980,7 +985,7 @@ void Kinetophone_narrator_view::mf_about()
   AboutDialog about_dialog;
   about_dialog.set_transient_for(*m_main_window);
   about_dialog.set_program_name("Kinetophone Narrator");
-  about_dialog.set_copyright("Copyright 2011-2012 Roan Trail, Inc.");
+  about_dialog.set_copyright("Copyright 2011-2013 Roan Trail, Inc.");
 
   stringstream license;
   license << "Kinetophone is free software: you can redistribute it and/or modify" << endl;
