@@ -1,6 +1,6 @@
 // Kinetophone_narrator_view.hpp
 //
-// Copyright 2011-2012 Roan Trail, Inc.
+// Copyright 2011-2013 Roan Trail, Inc.
 //
 // This file is part of Kinetophone.
 //
@@ -16,8 +16,8 @@
 // a copy of the GNU General Public License along with Kinetophone. If
 // not, see <http://www.gnu.org/licenses/>.
 
-#ifndef KINETOPHONE_NARRATOR_VIEW_HPP_
-#define KINETOPHONE_NARRATOR_VIEW_HPP_
+#ifndef ROAN_TRAIL_KINETOPHONE_APP_KINETOPHONE_NARRATOR_VIEW_HPP_
+#define ROAN_TRAIL_KINETOPHONE_APP_KINETOPHONE_NARRATOR_VIEW_HPP_
 
 #include <string>
 #include <vector>
@@ -32,10 +32,13 @@ namespace Gtk
 
 namespace Roan_trail
 {
-  class Error;
-  class Error_param;
-
   namespace Kinetophone
+  {
+    class Error;
+    class Error_param;
+  }
+
+  namespace Kinetophone_app
   {
     class Kinetophone_narrator_model;
     class Kinetophone_narrator_config;
@@ -81,11 +84,11 @@ namespace Roan_trail
       void toggle_metering();
       void reset_clipped();
       void show_session_info(const std::string& message);
-      int show_error(const Error& error, bool is_warning);
+      int show_error(const Roan_trail::Kinetophone::Error& error, bool is_warning);
       bool ask_overwrite_recording();
       static void output_console(const std::string& message);
       static void output_error(const std::string& message);
-      static bool list_devices(Error_param& return_error);
+      static bool list_devices(Roan_trail::Kinetophone::Error_param& return_error);
     protected:
       // invariant check
       bool mf_invariant(bool check_base_class = true) const;
@@ -148,4 +151,4 @@ namespace Roan_trail
   }
 }
 
-#endif // KINETOPHONE_NARRATOR_VIEW_HPP_
+#endif // ROAN_TRAIL_KINETOPHONE_APP_KINETOPHONE_NARRATOR_VIEW_HPP_
