@@ -1,6 +1,6 @@
 // Kinetophone_narrator_window.cpp
 //
-// Copyright 2011-2012 Roan Trail, Inc.
+// Copyright 2011-2013 Roan Trail, Inc.
 //
 // This file is part of Kinetophone.
 //
@@ -65,11 +65,11 @@
 #include "Level_meter_widget.hpp"
 #include "Scaled_image_widget.hpp"
 #include "Kinetophone_narrator_config.hpp"
-#include "../base/Application.hpp"
-#include "../base/common.hpp"
-#include "../base/Sound_recorder_config.hpp"
-#include "../base/Sound_file_config.hpp"
-#include "../base/error/Kinetophone_error.hpp"
+#include <kinetophone/Application.hpp>
+#include <kinetophone/common.hpp>
+#include <kinetophone/Sound_recorder_config.hpp>
+#include <kinetophone/Sound_file_config.hpp>
+#include <kinetophone/error/Kinetophone_error.hpp>
 #include <string>
 
 using Glib::RefPtr;
@@ -109,7 +109,8 @@ using Pango::FontDescription;
 using sigc::connection;
 using sigc::mem_fun;
 using std::string;
-using namespace Roan_trail::Kinetophone;
+using Roan_trail::Kinetophone::Application;
+using namespace Roan_trail::Kinetophone_app;
 
 //
 // Internal constants
