@@ -1,6 +1,6 @@
 // Level_meter_widget.cpp
 //
-// Copyright 2011-2012 Roan Trail, Inc.
+// Copyright 2011-2013 Roan Trail, Inc.
 //
 // This file is part of Kinetophone.
 //
@@ -22,9 +22,9 @@
 #include <gdkmm/drawable.h>
 #include <gdkmm/general.h>
 
-#include "../base/common.hpp"
-#include "../base/Level_meter_view.hpp"
-#include "../base/error/Error.hpp"
+#include <kinetophone/common.hpp>
+#include <kinetophone/Level_meter_view.hpp>
+#include <kinetophone/error/Error.hpp>
 #include <vector>
 #include <cstddef>
 #include <cstring>
@@ -36,9 +36,11 @@ using Glib::RefPtr;
 using Gtk::Allocation;
 using Gtk::Requisition;
 using std::vector;
-using Roan_trail::Error_param;
 using namespace Gdk::Cairo;
-using namespace Roan_trail::Kinetophone;
+using Roan_trail::Kinetophone::Level_meter_view;
+using Roan_trail::Kinetophone::min;
+using Roan_trail::Kinetophone::Error_param;
+using namespace Roan_trail::Kinetophone_app;
 
 namespace
 {
