@@ -1,6 +1,6 @@
 // Scaled_image_widget.cpp
 //
-// Copyright 2011-2012 Roan Trail, Inc.
+// Copyright 2011-2013 Roan Trail, Inc.
 //
 // This file is part of Kinetophone.
 //
@@ -23,8 +23,8 @@
 #include <gdkmm/general.h>
 #include <gdkmm/pixbuf.h>
 
-#include "../base/common.hpp"
-#include "../base/error/Error.hpp"
+#include <kinetophone/common.hpp>
+#include <kinetophone/error/Error.hpp>
 #include <iostream>
 #include <cstring>
 
@@ -36,9 +36,9 @@ using Glib::RefPtr;
 using Gtk::Allocation;
 using Gtk::Requisition;
 using Gtk::Widget;
-using Roan_trail::Error_param;
 using namespace Gdk::Cairo;
-using namespace Roan_trail::Kinetophone;
+using Roan_trail::Kinetophone::Error_param;
+using namespace Roan_trail::Kinetophone_app;
 
 namespace
 {
