@@ -1,6 +1,6 @@
 // Kinetophone_vox_app.cpp
 //
-// Copyright 2011-2012 Roan Trail, Inc.
+// Copyright 2011-2013 Roan Trail, Inc.
 //
 // This file is part of Kinetophone.
 //
@@ -26,10 +26,10 @@
 #include "Kinetophone_vox_manager.hpp"
 #include "Kinetophone_vox_model.hpp"
 #include "Kinetophone_vox_view.hpp"
-#include "../base/Logger.hpp"
-#include "../base/Speech_synthesizer_config.hpp"
-#include "../base/Slide_collection.hpp"
-#include "../base/error/Kinetophone_error.hpp"
+#include <kinetophone/Logger.hpp>
+#include <kinetophone/Speech_synthesizer_config.hpp>
+#include <kinetophone/Slide_collection.hpp>
+#include <kinetophone/error/Kinetophone_error.hpp>
 #include <memory>
 #include <iostream>
 #include <sstream>
@@ -49,8 +49,10 @@ using std::string;
 using std::stringstream;
 using Gdk::Pixbuf;
 using Gtk::Main;
-using Roan_trail::Logger;
-using namespace Roan_trail::Kinetophone;
+using Roan_trail::Kinetophone::Logger;
+using Roan_trail::Kinetophone::Error_param;
+using Roan_trail::Kinetophone::Kinetophone_error;
+using namespace Roan_trail::Kinetophone_app;
 
 //
 // Internal helpers
