@@ -17,13 +17,13 @@
 // not, see <http://www.gnu.org/licenses/>.
 
 #include "Kinetophone_vox_config.hpp"
-#include "../base/Speech_synthesizer_config.hpp"
-#include "../base/Sound_file_config.hpp"
-#include "../base/File_manager.hpp"
-#include "../base/option_checks.hpp"
-#include "../base/Option_validators.hpp"
-#include "../base/error/Boost_error.hpp"
-#include "../base/error/Kinetophone_error.hpp"
+#include <kinetophone/Speech_synthesizer_config.hpp>
+#include <kinetophone/Sound_file_config.hpp>
+#include <kinetophone/File_manager.hpp>
+#include <kinetophone/option_checks.hpp>
+#include <kinetophone/Option_validators.hpp>
+#include <kinetophone/error/Boost_error.hpp>
+#include <kinetophone/error/Kinetophone_error.hpp>
 #include <boost/program_options.hpp>
 #include <boost/concept/assert.hpp>
 #include <boost/concept_check.hpp>
@@ -37,16 +37,19 @@ using std::ifstream;
 using std::logic_error;
 using std::string;
 using std::stringstream;
-using Roan_trail::File_manager;
-using Roan_trail::Options::check_conflicting_options;
-using Roan_trail::Options::check_option_dependency;
-using Roan_trail::Options::Directory_validator;
-using Roan_trail::Options::Positive_int_validator;
-using Roan_trail::Options::Str_to_str_lookup_validator;
-using Roan_trail::Options::Validator;
-using Roan_trail::Recorder::Sound_file_config;
-using Roan_trail::Recorder::Speech_synthesizer_config;
-using namespace Roan_trail::Kinetophone;
+using Roan_trail::Kinetophone::File_manager;
+using Roan_trail::Kinetophone::check_conflicting_options;
+using Roan_trail::Kinetophone::check_option_dependency;
+using Roan_trail::Kinetophone::Directory_validator;
+using Roan_trail::Kinetophone::Positive_int_validator;
+using Roan_trail::Kinetophone::Str_to_str_lookup_validator;
+using Roan_trail::Kinetophone::Validator;
+using Roan_trail::Kinetophone::Sound_file_config;
+using Roan_trail::Kinetophone::Speech_synthesizer_config;
+using Roan_trail::Kinetophone::Boost_error;
+using Roan_trail::Kinetophone::Error_param;
+using Roan_trail::Kinetophone::Kinetophone_error;
+using namespace Roan_trail::Kinetophone_app;
 
 namespace PO = boost::program_options;
 
@@ -334,8 +337,8 @@ const int Kinetophone_vox_config::command_help;
 const int Kinetophone_vox_config::command_output_version;
 
 int Kinetophone_vox_config::parse_program_options(int argc,
-                                                       const char** argv,
-                                                       Error_param& return_error)
+                                                  const char** argv,
+                                                  Error_param& return_error)
 {
   precondition(!return_error());
 
