@@ -1,6 +1,6 @@
 // Kinetophone_vox_config.hpp
 //
-// Copyright 2011-2012 Roan Trail, Inc.
+// Copyright 2011-2013 Roan Trail, Inc.
 //
 // This file is part of Kinetophone.
 //
@@ -16,21 +16,20 @@
 // a copy of the GNU General Public License along with Kinetophone. If
 // not, see <http://www.gnu.org/licenses/>.
 
-#ifndef KINETOPHONE_VOX_CONFIG_HPP_
-#define KINETOPHONE_VOX_CONFIG_HPP_
+#ifndef ROAN_TRAIL_KINETOPHONE_APP_KINETOPHONE_VOX_CONFIG_HPP_
+#define ROAN_TRAIL_KINETOPHONE_APP_KINETOPHONE_VOX_CONFIG_HPP_
 
 #include <string>
 
 namespace Roan_trail
 {
-  class Error_param;
-
-  namespace Recorder
+  namespace Kinetophone
   {
+    class Error_param;
     class Speech_synthesizer_config;
   }
 
-  namespace Kinetophone
+  namespace Kinetophone_app
   {
     // Helper struct to store vox application settings.
     // It is a struct instead of a class since it primarily only
@@ -62,7 +61,7 @@ namespace Roan_trail
       bool detailed_error;
       bool quit_on_pregenerate_warnings;
       std::string custom_installation_dir;
-      Roan_trail::Recorder::Speech_synthesizer_config* speech_synthesizer_config;
+      Roan_trail::Kinetophone::Speech_synthesizer_config* speech_synthesizer_config;
       // command class constants
       static const int command_error          = 0;
       static const int command_synthesize     = 1;
@@ -71,9 +70,9 @@ namespace Roan_trail
       //
       int parse_program_options(int argc,
                                 const char** argv,
-                                Error_param& return_error);
+                                Roan_trail::Kinetophone::Error_param& return_error);
     };
   }
 }
 
-#endif // KINETOPHONE_VOX_CONFIG_HPP_
+#endif // ROAN_TRAIL_KINETOPHONE_APP_KINETOPHONE_VOX_CONFIG_HPP_
