@@ -1,6 +1,6 @@
 // Kinetophone_vox_model.cpp
 //
-// Copyright 2011-2012 Roan Trail, Inc.
+// Copyright 2011-2013 Roan Trail, Inc.
 //
 // This file is part of Kinetophone.
 //
@@ -22,13 +22,13 @@
 #include <gdkmm/pixbuf.h>
 
 #include "Kinetophone_vox_config.hpp"
-#include "../narrator/Kinetophone_dir_slide_collection.hpp"
-#include "../narrator/Kinetophone_PDF_slide_collection.hpp"
-#include "../base/File_manager.hpp"
-#include "../base/Narration_synthesizer.hpp"
-#include "../base/Slide_collection.hpp"
-#include "../base/error/Kinetophone_error.hpp"
-#include "../base/error/Posix_error.hpp"
+#include <kinetophone/File_manager.hpp>
+#include <kinetophone/Narration_synthesizer.hpp>
+#include <kinetophone/Slide_collection.hpp>
+#include <kinetophone/error/Kinetophone_error.hpp>
+#include <kinetophone/error/Posix_error.hpp>
+#include <kinetophone/Dir_slide_collection_glib.hpp>
+#include <kinetophone/PDF_slide_collection_glib.hpp>
 #include <libxml++/document.h>
 #include <libxml++/exceptions/exception.h>
 #include <libxml++/nodes/node.h>
@@ -46,12 +46,16 @@ using std::ofstream;
 using std::ios;
 using std::ios_base;
 using std::string;
-using Roan_trail::Error_param;
-using Roan_trail::File_manager;
-using Roan_trail::Recorder::Narration_synthesizer;
-using Roan_trail::Source::Slide_collection;
-using Roan_trail::Source::source_type_from_XML;
-using namespace Roan_trail::Kinetophone;
+using Roan_trail::Kinetophone::File_manager;
+using Roan_trail::Kinetophone::Narration_synthesizer;
+using Roan_trail::Kinetophone::Slide_collection;
+using Roan_trail::Kinetophone::source_type_from_XML;
+using Roan_trail::Kinetophone::Error_param;
+using Roan_trail::Kinetophone::Kinetophone_error;
+using Roan_trail::Kinetophone::Posix_error;
+using Roan_trail::Kinetophone_glib::Dir_slide_collection_glib;
+using Roan_trail::Kinetophone_glib::PDF_slide_collection_glib;
+using namespace Roan_trail::Kinetophone_app;
 
 //
 // Constructor/destructor
@@ -137,12 +141,12 @@ bool Kinetophone_vox_model::load_from_XML(const string& file_path, Error_param&
                                                      error()));
     if ("directory" == source_type_string)
     {
-      slides = new Kinetophone_dir_slide_collection;
+      slides = new Dir_slide_collection_glib;
       slides_source = directory_source;
     }
     else if ("PDF" == source_type_string)
     {
-      slides = new Kinetophone_PDF_slide_collection;
+      slides = new PDF_slide_collection_glib;
       slides_source = PDF_source;
     }
     else
@@ -204,12 +208,12 @@ bool Kinetophone_vox_model::load_from_PDF_source(const string& PDF_source_path,
   precondition(!return_error()
                && mf_invariant());
 
-  Kinetophone_PDF_slide_collection* slides = 0;
+  PDF_slide_collection_glib* slides = 0;
   bool return_value = false;
 
   start_error_block();
 
-  slides = new Kinetophone_PDF_slide_collection;
+  slides = new PDF_slide_collection_glib;
   slides->set_import_PDF_notes(true);
 
   Error_param error;
