@@ -1,6 +1,6 @@
 // Kinetophone_vox_model.hpp
 //
-// Copyright 2012 Roan Trail, Inc.
+// Copyright 2012-2013 Roan Trail, Inc.
 //
 // This file is part of Kinetophone.
 //
@@ -16,8 +16,8 @@
 // a copy of the GNU General Public License along with Kinetophone. If
 // not, see <http://www.gnu.org/licenses/>.
 
-#ifndef KINETOPHONE_VOX_MODEL_HPP_
-#define KINETOPHONE_VOX_MODEL_HPP_
+#ifndef ROAN_TRAIL_KINETOPHONE_APP_KINETOPHONE_VOX_MODEL_HPP_
+#define ROAN_TRAIL_KINETOPHONE_APP_KINETOPHONE_VOX_MODEL_HPP_
 
 #include <string>
 
@@ -33,18 +33,14 @@ namespace Glib
 
 namespace Roan_trail
 {
-  class Error_param;
-
-  namespace Recorder
+  namespace Kinetophone
   {
+    class Error_param;
     class Narration_synthesizer;
-  }
-  namespace Source
-  {
     template <class Image> class Slide_collection;
   }
 
-  namespace Kinetophone
+  namespace Kinetophone_app
   {
     class Kinetophone_vox_config;
 
@@ -61,23 +57,24 @@ namespace Roan_trail
       Kinetophone_vox_model(const Kinetophone_vox_config& vox_config);
       ~Kinetophone_vox_model();
       // accessors
-      const Roan_trail::Source::Slide_collection<Glib::RefPtr<Gdk::Pixbuf> >* slides() const { return m_slides; }
-      Roan_trail::Source::Slide_collection<Glib::RefPtr<Gdk::Pixbuf> >* slides() { return m_slides; }
-      Roan_trail::Recorder::Narration_synthesizer* narration_synthesizer() { return m_synthesizer; }
-      const Roan_trail::Recorder::Narration_synthesizer* narration_synthesizer() const { return m_synthesizer; }
+      const Roan_trail::Kinetophone::Slide_collection<Glib::RefPtr<Gdk::Pixbuf> >* slides() const { return m_slides; }
+      Roan_trail::Kinetophone::Slide_collection<Glib::RefPtr<Gdk::Pixbuf> >* slides() { return m_slides; }
+      Roan_trail::Kinetophone::Narration_synthesizer* narration_synthesizer() { return m_synthesizer; }
+      const Roan_trail::Kinetophone::Narration_synthesizer* narration_synthesizer() const { return m_synthesizer; }
       // load/save
-      bool load_from_XML(const std::string& file_path, Error_param& return_error);
-      bool load_from_PDF_source(const std::string& PDF_source_path, Error_param& return_error);
+      bool load_from_XML(const std::string& file_path, Roan_trail::Kinetophone::Error_param& return_error);
+      bool load_from_PDF_source(const std::string& PDF_source_path,
+                                Roan_trail::Kinetophone::Error_param& return_error);
       bool save_as_XML(const std::string& file_path,
                        bool overwrite,
-                       Error_param& return_error) const;
+                       Roan_trail::Kinetophone::Error_param& return_error) const;
     protected:
       // invariant check
       bool mf_invariant(bool check_base_class = true) const;
     private:
       const Kinetophone_vox_config& m_vox_config;
-      Roan_trail::Source::Slide_collection<Glib::RefPtr<Gdk::Pixbuf> >* m_slides;
-      Roan_trail::Recorder::Narration_synthesizer* m_synthesizer;
+      Roan_trail::Kinetophone::Slide_collection<Glib::RefPtr<Gdk::Pixbuf> >* m_slides;
+      Roan_trail::Kinetophone::Narration_synthesizer* m_synthesizer;
       Slides_source_type m_slides_source;
       // prevent compiler from generating
       Kinetophone_vox_model(const Kinetophone_vox_model& vox_model);
@@ -86,4 +83,4 @@ namespace Roan_trail
   }
 }
 
-#endif // KINETOPHONE_VOX_MODEL_HPP_
+#endif // ROAN_TRAIL_KINETOPHONE_APP_KINETOPHONE_VOX_MODEL_HPP_
